@@ -12,9 +12,8 @@
 # Library General Public License for more details.
 #
 # You should have received a copy of the GNU Library General Public
-# License along with this library; if not, write to the 
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
-# Boston, MA  02111-1307  USA.
+# License along with this library; if not, see
+# <https://www.gnu.org/licenses/>.
 
 package Gnome2::GConf;
 
@@ -24,33 +23,15 @@ use warnings;
 
 use Glib;
 
-require Exporter;
+require DynaLoader;
 
-our @ISA = qw(Exporter);
+our @ISA = qw(DynaLoader);
 
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Gnome2::GConf ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-	
-);
-
-our $VERSION = '1.043';
+our $VERSION = '1.045';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
-require XSLoader;
-XSLoader::load('Gnome2::GConf', $VERSION);
+Gnome2::GConf->bootstrap ($VERSION);
 
 
 # Preloaded methods go here
@@ -299,8 +280,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.
 
 You should have received a copy of the GNU Library General Public
-License along with this library; if not, write to the 
-Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
-Boston, MA  02111-1307  USA.
+License along with this library; if not, see
+<https://www.gnu.org/licenses/>.
 
 =cut
